@@ -40,8 +40,8 @@ if __name__ == '__main__':
     # gen_exports('recorders')
     # gen_exports('domain')
     # gen_exports('informer')
-    gen_exports('utils')
+    gen_exports('tag')
     # gen_exports('trader')
     # gen_exports('autocode')
-    gen_exports('factors')
+    gen_exports('ml')
     # gen_kdata_schemas()
